<?php 
/*
General functions of theme
*/

/////////////////////////////////////////////////
//
// ADD ATTACHMENTS
//
/////////////////////////////////////////////////
global $data;
function add_attachment($file) {
	
	$url = $file['url'];
	$type = $file['type'];
	$file = $file['file'];
	$filename = basename($file);

	// Construct the attachment array
	$attachment = array(
		'post_title' => $filename,
		'post_content' => $descr,
		'post_type' => 'attachment',
		'post_parent' => $post,
		'post_mime_type' => $type,
		'guid' => $url
	);

	// Save the data
	$id = wp_insert_attachment($attachment, $file, $post);
	if (preg_match('!^image/!', $attachment['post_mime_type'])) {
		$imagesize = getimagesize($file);
		$imagedata['width'] = $imagesize['0'];
		$imagedata['height'] = $imagesize['1'];
		list($uwidth, $uheight) = get_udims($imagedata['width'], $imagedata['height']);
		$imagedata['hwstring_small'] = "height='$uheight' width='$uwidth'";
		$imagedata['file'] = $file;
		add_post_meta($id, '_wp_attachment_metadata', $imagedata);
	}
}




/**
 * Title         : Aqua Resizer
 * Description   : Resizes WordPress images on the fly
 * Version       : 1.1.7
 * Author        : Syamil MJ
 * Author URI    : http://aquagraphite.com
 * License       : WTFPL - http://sam.zoy.org/wtfpl/
 * Documentation : https://github.com/sy4mil/Aqua-Resizer/
 *
 * @param string  $url    - (required) must be uploaded using wp media uploader
 * @param int     $width  - (required)
 * @param int     $height - (optional)
 * @param bool    $crop   - (optional) default to soft crop
 * @param bool    $single - (optional) returns an array if false
 * @uses  wp_upload_dir()
 * @uses  image_resize_dimensions() | image_resize()
 * @uses  wp_get_image_editor()
 *
 * @return str|array
 */

function aq_resize( $url, $width = null, $height = null, $crop = null, $single = true, $upscale = false ) {

	// Validate inputs.
	if ( ! $url || ( ! $width && ! $height ) ) return false;

	// Caipt'n, ready to hook.
	if ( true === $upscale ) add_filter( 'image_resize_dimensions', 'aq_upscale', 10, 6 );

	// Define upload path & dir.
	$upload_info = wp_upload_dir();
	$upload_dir = $upload_info['basedir'];
	$upload_url = $upload_info['baseurl'];

	$http_prefix = "http://";
	$https_prefix = "https://";

	/* if the $url scheme differs from $upload_url scheme, make them match 
	   if the schemes differe, images don't show up. */
	if(!strncmp($url,$https_prefix,strlen($https_prefix))){ //if url begins with https:// make $upload_url begin with https:// as well
		$upload_url = str_replace($http_prefix,$https_prefix,$upload_url);
	}
	elseif(!strncmp($url,$http_prefix,strlen($http_prefix))){ //if url begins with http:// make $upload_url begin with http:// as well
		$upload_url = str_replace($https_prefix,$http_prefix,$upload_url);		
	}


	// Check if $img_url is local.
	if ( false === strpos( $url, $upload_url ) ) return false;

	// Define path of image.
	$rel_path = str_replace( $upload_url, '', $url );
	$img_path = $upload_dir . $rel_path;

	// Check if img path exists, and is an image indeed.
	if ( ! file_exists( $img_path ) or ! getimagesize( $img_path ) ) return false;

	// Get image info.
	$info = pathinfo( $img_path );
	$ext = $info['extension'];
	list( $orig_w, $orig_h ) = getimagesize( $img_path );

	// Get image size after cropping.
	$dims = image_resize_dimensions( $orig_w, $orig_h, $width, $height, $crop );
	$dst_w = $dims[4];
	$dst_h = $dims[5];

	// Return the original image only if it exactly fits the needed measures.
	if ( ! $dims && ( ( ( null === $height && $orig_w == $width ) xor ( null === $width && $orig_h == $height ) ) xor ( $height == $orig_h && $width == $orig_w ) ) ) {
		$img_url = $url;
		$dst_w = $orig_w;
		$dst_h = $orig_h;
	} else {
		// Use this to check if cropped image already exists, so we can return that instead.
		$suffix = "{$dst_w}x{$dst_h}";
		$dst_rel_path = str_replace( '.' . $ext, '', $rel_path );
		$destfilename = "{$upload_dir}{$dst_rel_path}-{$suffix}.{$ext}";

		if ( ! $dims || ( true == $crop && false == $upscale && ( $dst_w < $width || $dst_h < $height ) ) ) {
			// Can't resize, so return false saying that the action to do could not be processed as planned.
			return false;
		}
		// Else check if cache exists.
		elseif ( file_exists( $destfilename ) && getimagesize( $destfilename ) ) {
			$img_url = "{$upload_url}{$dst_rel_path}-{$suffix}.{$ext}";
		}
		// Else, we resize the image and return the new resized image url.
		else {

			// Note: This pre-3.5 fallback check will edited out in subsequent version.
			if ( function_exists( 'wp_get_image_editor' ) ) {

				$editor = wp_get_image_editor( $img_path );

				if ( is_wp_error( $editor ) || is_wp_error( $editor->resize( $width, $height, $crop ) ) )
					return false;

				$resized_file = $editor->save();

				if ( ! is_wp_error( $resized_file ) ) {
					$resized_rel_path = str_replace( $upload_dir, '', $resized_file['path'] );
					$img_url = $upload_url . $resized_rel_path;
				} else {
					return false;
				}

			} else {

				$resized_img_path = image_resize( $img_path, $width, $height, $crop ); // Fallback foo.
				if ( ! is_wp_error( $resized_img_path ) ) {
					$resized_rel_path = str_replace( $upload_dir, '', $resized_img_path );
					$img_url = $upload_url . $resized_rel_path;
				} else {
					return false;
				}

			}

		}
	}

	// Okay, leave the ship.
	if ( true === $upscale ) remove_filter( 'image_resize_dimensions', 'aq_upscale' );

	// Return the output.
	if ( $single ) {
		// str return.
		$image = $img_url;
	} else {
		// array return.
		$image = array (
			0 => $img_url,
			1 => $dst_w,
			2 => $dst_h
		);
	}

	return $image;
}


function aq_upscale( $default, $orig_w, $orig_h, $dest_w, $dest_h, $crop ) {
	if ( ! $crop ) return null; // Let the wordpress default function handle this.

	// Here is the point we allow to use larger image size than the original one.
	$aspect_ratio = $orig_w / $orig_h;
	$new_w = $dest_w;
	$new_h = $dest_h;

	if ( ! $new_w ) {
		$new_w = intval( $new_h * $aspect_ratio );
	}

	if ( ! $new_h ) {
		$new_h = intval( $new_w / $aspect_ratio );
	}

	$size_ratio = max( $new_w / $orig_w, $new_h / $orig_h );

	$crop_w = round( $new_w / $size_ratio );
	$crop_h = round( $new_h / $size_ratio );

	$s_x = floor( ( $orig_w - $crop_w ) / 2 );
	$s_y = floor( ( $orig_h - $crop_h ) / 2 );

	return array( 0, 0, (int) $s_x, (int) $s_y, (int) $new_w, (int) $new_h, (int) $crop_w, (int) $crop_h );
}


/////////////////////////////////////////////////
//
// IMAGE RESIZE
//
/////////////////////////////////////////////////
function wm_image_resize($width, $height, $img_url,$crop='') {	

	global $data;
		
	////check portrait or landscape////
	    $path_arr = parse_url($img_url);
		$hostname = $path_arr["scheme"].$path_arr["host"];
		$img_url = str_replace($hostname,"",$img_url);

		$size = getimagesize($img_url); 
		$width_img = $size[0]; 
		$height_img = $size[1]; 
		$aspect = $height_img / $width_img; 
		if ($aspect >= 1) $crop_mode = false; //portrait
		else $crop_mode = true;  //landscape
   ////// End /////////

	if($data["wm_thumbnail_generator"]=="Enable Timthumb") { //TimThumb
	
		global  $blog_id; 
		$quality = 100;
		$url = get_template_directory_uri();
		
		/////crop image location ////
		if($crop != '')
			$timthumb_crop_location =  $crop;
		else
			$timthumb_crop_location = $data["wm_timthumb_crop_location"];

			$query_crop_location = "";
		if($timthumb_crop_location == 'Align top')
			$query_crop_location = '&amp;a=t';
		elseif($timthumb_crop_location == 'Align top right')
			$query_crop_location = '&amp;a=tr';
		elseif($timthumb_crop_location == 'Align top left')
			$query_crop_location = '&amp;a=tl';
		elseif($timthumb_crop_location == 'Align bottom')
			$query_crop_location = '&amp;a=b';
		elseif($timthumb_crop_location == 'Align bottom right')
			$query_crop_location = '&amp;a=br';
		elseif($timthumb_crop_location == 'Align bottom left')
			$query_crop_location = '&amp;a=bl';
		elseif($timthumb_crop_location == 'Align left')
			$query_crop_location = '&amp;a=l';
		elseif($timthumb_crop_location == 'Align right')
			$query_crop_location = '&amp;a=r';
		//////////// end crop location ////////	
		

		if ($r_resize == 'yes' || !isset($r_resize)) {

		  //There's a thumbnail image set, so check if we're on WPMU or WP
			if (isset($blog_id) && $blog_id > 0)
			{
				//We're on WPMU		
				$imageParts = explode('/files/', $img_url);			   
				if (isset($imageParts[1]))
				{
					$img_url = '/blogs.dir/' . $blog_id . '/files/' . $imageParts[1];
					$img_url = $url.'/timthumb.php?src='.$img_url.'&amp;w='.$width.'&amp;h='.$height.'&amp;zc=1&amp;q='.$quality;
				}
				else{
					$img_url = $url.'/timthumb.php?src='.$img_url.'&amp;w='.$width.'&amp;h='.$height.'&amp;zc=1&amp;q='.$quality;
				}
			}
			else
			{
				
				$img_url = $url.'/timthumb.php?src='.$img_url.'&amp;w='.$width.'&amp;h='.$height.'&amp;zc=1&amp;q='.$quality;
			}
		}
		else $img_url = $img_url;
		
		$img_url = $img_url.$query_crop_location;
	}
	elseif($data["wm_thumbnail_generator"]=="Enable WP Image Resize") { //WP Image Resize

		$image = vt_resize('', $img_url, $width, $height,true); 
		$img_url = $image['url'];
	}
	else { //default resize
	
		$img_url =  aq_resize($img_url, $width, $height,true,true,true);
		
	}

	return urldecode($img_url);
}

